<?php
/**
 *  Base Class for creating admin panels based on IOA Framework
 *  @class : IOA_PANEL_CORE
 *  @version : 3.5
 *  @author : Artillegence
 *  @package : IOA
 *  @category : class
 */


/**
*
* Check If Class Exists
*
**/


if(!class_exists('IOA_PANEL_CORE')) {


  
  class IOA_PANEL_CORE {
	  
	  /**  Name of Admin Panel **/
	  private $name;

	  /**  Unique Preffix for Panel **/
	  private $panelName;

	  /**  Type of Menu **/
	  private $type;

	  /**  Side Icon for Panel **/
	  private $icon;

	  /**  User Access **/
	  private $role;


	 /**
	  *  Constrtuctor For Admin Maker 
	  *  @param string $name The Name of the Panel that will Appear in WP ADMIN side menu
	  *  @param string $type Type of Menu Defautl Page(Separate Menu) , supported values are page and submenu
	  *  @param string $panel_name	unique key name for panel( ex : admin.php?page=ULT ). Defaults to first 5 letters in capital.
	  *  @param string $icon The link to icon , set to false to use wp default icon. 
	  *  @param string $role The role/level required to access the panel. 
	  */
	 
     	 function __construct($name,$type='page',$panel_name=false, $icon = false,$role = 'edit_pages') { 
	  
		$this->name = $name;
		
		/**
		*
		* Convert First 5 letter of name to Panel name
		*
		**/
		
		if(!$panel_name)
			$this->panelName = strtolower(substr($name,0,5));
		else
			$this->panelName = 	$panel_name;
		
		$this->type = $type;
		
		/**
		*
		* Set Icon for Panel , if false set default Icon. Set NULL for WP Default Icon
		*
		**/
				

		if(!$icon)
			$this->icon  =  NULL;
		else
			$this->icon = $icon;
		
		$this->role= $role;

		/**
		*
		*  Add WP Hooks for Adding to Menu and Init
		*
		**/
		

		add_action('admin_menu',array(&$this,'manager_admin_menu'));
      		add_action('admin_init',array(&$this,'manager_admin_init'));
		
	  }

	  /**
	   * Register Panel  to Wordpress Side Menu
	   */

	  function manager_admin_menu(){
	
	   	switch($this->type)
	   	{
		   case 'page' : add_menu_page( $this->name,  $this->name , $this->role, $this->panelName ,array($this,'manager_admin_wrap'),  $this->icon);  break;
		   case 'submenu':  add_submenu_page("ioawel", $this->name, $this->name, $this->role, $this->panelName ,array($this,'manager_admin_wrap')); break;
		   case 'null':  add_submenu_page(null, $this->name, $this->name, $this->role, $this->panelName ,array($this,'manager_admin_wrap')); break;
	   	}
		  
				  
	  }

	  /**
	   *  Function to include global panel data on wp admin init
	   */
		  
	  function manager_admin_init(){	
	 	 
	  
	    }	

	    /**
	     * Common Markup Panel function , extended in other panels for Structure 
	     */
	  
	  function panelmarkup() { }


	  /**
	   *  Function Wrap all IOA Panels in Common Wrapper 
	   *  Cannot be extened in Inherited Classes. Use panelmarkup function.
	   */

	  final function manager_admin_wrap(){	
	?>
	
	<!-- IOA WRAPPER BEGINS -->

	<div class="ioa_wrap">
		<div class="clearfix ioa_admin_panel"> 
			<?php $this->panelmarkup() ; ?>
		</div>
	</div> <!--END OF IOA WRAPPER  -->

	<?php

	}	  
	  
	 
       }  // ## END OF IOA_PANEL_CORE CLASS
     
	 
	
} // ## END OF IOA_PANEL_CORE CLASS Check
