<?php
/**
 *  Class to create Custom Posts 
 *  @class : IOACustomPost
 *  @version : 3.5
 *  @author : Artillegence
 *  @package : IOA
 *  @category : class
 */


/**
*
* Check If Class Exists
*
**/


if(!class_exists('IOACustomPost')) {


  class IOACustomPost {
  	
  	 /**  Custom Post Options **/
  	private $posts_options;

  	 /**  Custom Post Name **/
  	private $name;

  	 /**  Custom Post Taxonomy **/
  	private $taxonomy= '';

  	 /**  Label **/
  	private $label ='';

  	/** Plural Name of Post Type **/
 	 private $multi = '';
  	
  	/**
	  *  Constrtuctor For Post Type 
	  *  @param string $title Name of Post Type
	  *  @param string $ioa_options Custom Post Options
	  *  @param string $taxonomy	Taxonomy or Taxonomies for Post Type
	  *  @param string $plural Plural Name for Post Type
	  */

	  function __construct($title, $ioa_options = array() ,$taxonomy='',$plural='')
	  {
		 
	  	$title= ucwords($title);
	  	$this->label = $title;
	  	$this->multi = $plural;
	    
		$menu_icon = null;

	 	if( isset($ioa_options['labels']['post_icon']) && $ioa_options['labels']['post_icon']!= "" ) 
	 	   	$menu_icon = $ioa_options['labels']['post_icon'];

	 	 /**
	 	   *
	 	   * Values for Post Type
	 	   *
	 	   **/
	 	     

	  	$default_labels = array(
						  'name' => _x($title, 'post type general name','ioa'),
						  'singular_name' => _x($title, 'post type singular name','ioa'),
						  'add_new' => _x("Add New", $title,'ioa'),
						  'add_new_item' => _x("Add New ".$title,'ioa','ioa'),
						  'edit_item' => _x("Edit ".$title,'ioa'),
						  'new_item' => _x("New ".$title,'ioa'),
						  'all_items' => _x("All ".$plural,'ioa'),
						  'view_item' => _x("View ".$title,'ioa'),
						  'search_items' => _x("Search ".$plural,'ioa'),
						  'not_found' =>  __("Not Found",'ioa'),
						  'not_found_in_trash' => __("Not Found in Trash",'ioa'), 
						  'parent_item_colon' => "",
						  'menu_name' => $title
					  
						);

	 	$default_opts = array(
						  'labels' => $default_labels,
						  'description' => _x("Add your ".$title." here",'ioa'),
						  'public' => true,
						  'publicly_queryable' => true,
						  'show_ui' => true,
						  'exclude_from_search' => false,
						  'query_var' => true,
						  'rewrite' => true,
						  'capability_type' => 'post',
						  '_edit_link' => 'post.php?post=%d',
						  'hierarchical' => true,
						  'show_in_nav_menus' => true,
						  'supports' =>array('title','editor','thumbnail','excerpt'),
						  'menu_icon' => $menu_icon
						  );


	 	$ioa_options = array_merge($default_opts,$ioa_options);
		 $this->posts_options = $ioa_options;

		
		 $this->name = trim(str_replace(" ","",strtolower(strtolower($title))));
		 
		/**
		 *
		 * Register Post Type
		 *
		 **/
		  
		 
		 if(isset($this->posts_options['menu_icon']) && trim($this->posts_options['menu_icon'])=="")
			 $this->posts_options['menu_icon']  = NULL;
		 
		 add_action('init', array($this,'custom_register'));
		
		/**
		*
		* Set Taxonomies
		*
		**/
		

		if(trim($taxonomy)!="")
			$this->taxonomy = explode(",",$taxonomy);
		
	  }
  	
  	/**
  	 *  Get Post Type name (slug)
  	 *  @return : string
  	 */

	  function getPostType()
	  {
	   	return trim($this->name);
	  }

	/**
  	 *  Get Post Type Label
  	 *  @return : string
  	 */

	  function getPostLabel()
	  {
	  	return trim($this->label);
	  }

	 /**
  	 *  Get Plural Name
  	 *  @return : string
  	 */

	  function getPostMulti()
	  {
	  	return trim($this->multi);
	  }

	  /**
  	 *  Get Taxonomies
  	 *  @return : string
  	 */

	  function getTax()
	  {
	  	return $this->taxonomy;
	  }
	
	/**
	   * Register the Post type and taxonomy
	   */  

	function custom_register()
	{
		/** Register Post Type **/
		register_post_type( $this->name , $this->posts_options );

		/**
		*
		* Register Taxonomy or Taxonomies
		*
		**/
		

		if( isset($this->taxonomy) && is_array($this->taxonomy) && $this->taxonomy !=""  )
		{
			foreach($this->taxonomy as $tax)
			{

			if(trim($tax)!="" )
				register_taxonomy(
					trim(str_replace(" ","",strtolower($tax))), 
					array($this->name), 
					array(
						"hierarchical" => true, 
						"labels" => array( 'name' => $tax  ) , 
						"singular_label" => "type", 
						"rewrite" => true
					)
				);
			}
		}

	}
	 
        }   // ## END OF IOACustomPost CLASS
	   
	   
  }  // ## END OF IOACustomPost CLASS Exists
  
   