<?php

/**
 * The file that defines the core plugin class
 *
 * A class definition that includes attributes and functions used across both the
 * public-facing side of the site and the admin area.
 *
 * @link       http://example.com
 * @since      1.0.0
 *
 * @package    leap_chat
 * @subpackage leap_chat/includes
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}


/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 * @package    leap_chat
 * @subpackage leap_chat/includes
 * @author     Your Name <email@example.com>
 */
class leap_chat {

	protected static $_instance;
	/**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      leap_chat_Loader    $loader    Maintains and registers all hooks for the plugin.
	 */
	protected $loader;

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $plugin_name    The string used to uniquely identify this plugin.
	 */
	protected $plugin_name;

	/**
	 * The current version of the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $version    The current version of the plugin.
	 */
	protected $version;

	/**
	 * Define the core functionality of the plugin.
	 *
	 * Set the plugin name and the plugin version that can be used throughout the plugin.
	 * Load the dependencies, define the locale, and set the hooks for the admin area and
	 * the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function __construct() {

		$this->plugin_name = 'Leap Chat';
		$this->version = '1.0.0';

		$this->load_dependencies();
		$this->set_locale();
		$this->define_admin_hooks();
		$this->define_public_hooks();

	}

	/**
	 * Main  Instance
	 *
	 * Ensures only one instance  is loaded or can be loaded.
	 */
	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Include the following files that make up the plugin:
	 *
	 * - leap_chat_Loader. Orchestrates the hooks of the plugin.
	 * - leap_chat_i18n. Defines internationalization functionality.
	 * - leap_chat_Admin. Defines all hooks for the admin area.
	 * - leap_chat_Public. Defines all hooks for the public side of the site.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function load_dependencies() {

		/**
		 * The class responsible for orchestrating the actions and filters of the
		 * core plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-leap_chat-loader.php';

		/**
		 * The class responsible for defining internationalization functionality
		 * of the plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-leap_chat-i18n.php';

		/**
		 * The class responsible for defining all actions that occur in the admin area.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/superloader.php';


		$this->loader = new leap_chat_Loader();

	}

	/**
	 * Define the locale for this plugin for internationalization.
	 *
	 * Uses the leap_chat_i18n class in order to set the domain and to register the hook
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function set_locale() {

		


	}


	/**
	 * Register Admin scripts for plugin.
	 * 
	 * */

	public function registerScripts()
	{

		
			global $pagenow;

			$suffix = '.min';
			if(leap_chat_DEV_MODE)
				$suffix = '';
			
			wp_enqueue_script('jquery-ui-slider');

			if(leap_chat_DEV_MODE)	
				wp_enqueue_script('jquery-minicolors',leap_chat_URL.'/admin/js/jquery.minicolors.js');

			wp_enqueue_script('jquery-material',leap_chat_URL.'/admin/js/material.min.js',array(),false,true);
			wp_enqueue_script('jquery-ripples',leap_chat_URL.'/admin/js/ripples.min.js',array(),false,true);
			
			
			wp_register_script('leap-admin-js',leap_chat_URL.'/admin/js/global'.$suffix.'.js',array(),false,true);

			wp_enqueue_style('leap-font-icons',leap_chat_URL."/sprites/fonts/theme-fonts.css",array() );
			wp_enqueue_style('global-plugin-css',leap_chat_URL.'/admin/css/global.css');
			wp_enqueue_script('wp-mediaelement',false,array(),false,true);

			$media_import_array = array("lchatop",'lchat');

			if( (  isset($_GET['page']) && in_array($_GET['page'],$media_import_array ) )  ||  $pagenow == 'profile.php' || $pagenow == 'user-edit.php')
				wp_enqueue_media();

			$translation_array = array( 

				'is_typing' => __("User is Typing",'leap'),
				'connecting' => __('Connecting...','leap'),
				'connected' => __('Connected','leap'),
				'connecting' => __('Connecting...','leap'),
				'na' => __('Not Available','leap'),
				'cache_title' =>  __('Cache Deleted !','leap'),
				'cache_desc' =>  __( 'All dead sessions have been removed succcessfully.','leap'),

				'analytics_title' =>  __( 'Analytics Deleted !','leap'),
				'analytics_desc' =>  __( 'All data has been removed succcessfully.','leap'),

				'ochat_title' =>  __( 'Not Allowed !','leap'),
				'ochat_desc' =>  __( 'Chat is already assigned to an operator.','leap'),

				'options_title' =>  __( 'Settings Saved !','leap'),
				'options_desc' =>  __( 'Your settings have been saved succcessfully.','leap'),

				'end_con_title' =>  __( 'Ending Conversation','leap'),
				'end_con_desc' =>  __('Please Wait....','leap'),
				"disconnected" =>  __( 'Conversation Disconnected','leap'),
                "left" =>  __( 'User has left the chat','leap'),
				"duh" =>  __( 'No one is available for chat','leap'),

			  );
				
			wp_localize_script( 'leap-admin-js', 'leap_admin_localize', $translation_array );
			
			wp_enqueue_script('leap-admin-js');
	}

	/**
	 * Register scripts for plugin.
	 * 
	 * */

	public function registerChatScripts()
	{
			global $pagenow,$leap_google_webfonts;

			$suffix = '.min';
			if(leap_chat_DEV_MODE)
				$suffix = '';
			
			wp_enqueue_script('jquery');
			wp_enqueue_script('wp-mediaelement',false,array(),false,true);
			wp_enqueue_script('leap-js',leap_chat_URL.'/sprites/js/custom.js',array(),false,true);
			
			
			$translation_array = array( 

				'offline_message' => get_option('LEAP_offline_msg')

			  );
			
			wp_localize_script( 'custom', 'leap_localize', $translation_array );

			$font = get_option('LEAP_google_font');
			if( ! $font )
				$font = 'Open Sans';

			$req = str_replace(" ","+",$font);
			
			$link =  $req.":".$leap_google_webfonts[$font]['variants'];



			$link =  "fonts.googleapis.com/css?family=".$link;
			if(is_ssl())
				$link = "https://".$link;
			else
				$link = "http://".$link;
			wp_enqueue_style('leap-font', $link );
			wp_enqueue_style('leap-css',leap_chat_URL."/sprites/stylesheets/style.css",array() );

	}

	/**
	 * Register all of the hooks related to the admin area functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_admin_hooks() {

		add_action( 'admin_enqueue_scripts', array( $this, 'registerScripts' )  );
		

		/**
		 *  Register IOA Framework Posts
		 * 
		 * */
		 
		 function LEAP_addCannedMessage()
		{
			
			$newcpt = new IOACustomPost('Leap Canned Message',array(
					"supports" => array("title","editor")
				));
			
			$newcpt = new IOACustomPost('Leap Chat Archive',array( 
							   				  'publicly_queryable' => false,
											  'show_ui' => false,
											 'menu_position' => 100,
											  'exclude_from_search' => true,
											  'show_in_nav_menus' => false
											   ),"");
		}
		add_filter('after_setup_theme','LEAP_addCannedMessage'); 

		/**
		 * Meta Box for Canned Message Shortcode
		 * 
		 * **/
		
		function LEAP_CANNEDOPTS()
		{
			global $post;
			  ?>
				<h4><?php _e('Use this code in chat, to the print the message','leap') ?></h4>
				<div class="leap-shortcode">
					[leapcanned  <span class="leap-slug-listener"><?php if(isset($post)) echo $post->ID  ?></span>/]
				</div>
			  <?php
				

		}

		/**
		 *  Add IOA Layout and Customization Panel
		 * 
		 * */
		function LEAP_Addcannedbox() 
		{
			global $ioa_registered_posts;
			$screens = array( 'leapcannedmessage' );

			foreach ($screens as $screen) 
			{
			        	add_meta_box('LEAP_CANNEDOPTS',    __('Canned Message Code', 'leap'), 'LEAP_CANNEDOPTS', $screen, 'side' , 'high');
			 }
		}

		function LEAP_adminNotfication()
		{
			?>
			<div class="ioa-message">
		        
		     		 <div class="ioa-message-body clearfix">
				             
				               <div class="ioa-icon-area">
				               		<i class="ioa-front-icon checkicon-"></i>
				               </div>
				               <div class="ioa-info-area">
				               		<h3 class='msg-title'><?php _e('Settings Saved !','leap') ?></h3>
				               		<p class='msg-text'><?php _e('Options Panel Settings were saved at 11 PM','leap') ?></p>
				               </div>
		              
		        		  </div>
		  	
		  	 </div>
			<span class="waiting"></span>
			<?php
		}

		add_action( 'admin_footer', 'LEAP_adminNotfication');
		add_action( 'add_meta_boxes', 'LEAP_Addcannedbox');

		function LEAP_setUpAdmin()
		{
			$cuser =  get_current_user_id();
			
			$test = false;	
			$access_users = get_option('LEAP_chat_users');
			if($access_users &&  $access_users!='' ){

				$access_users = explode(',',$access_users);
				if(in_array($cuser,$access_users))
					$test = true;

			} else
			{
				if(current_user_can('activate_plugins'))
					$test = true;
			}

			if($test)
			new LEAPADMIN();
			new LEAPADMINOPTIONS();
			new LEAPADMINANALYTICS();
			new LEAPADMINARCHIVES();

			
		}

		add_action('init','LEAP_setUpAdmin');


		add_action( 'show_user_profile', 'LEAP_extra_profile_fields' );
		add_action( 'edit_user_profile', 'LEAP_extra_profile_fields' );

		function LEAP_extra_profile_fields( $user ) { 
			
			$pn = esc_attr( get_the_author_meta( 'custom_profile_image', $user->ID ) );
			$pn = LEAP_getImage($pn);
			$pn = $pn['src'];

			$desig = esc_attr( get_the_author_meta( 'leap_designation', $user->ID ) );
			?>

			<table class="form-table">
				<tr>
					<th><label for="custom_profile_image"><?php _e('Set Profile Image, image should be 50 px by 50px ','leap') ?></label></th>

					<td class="image_upload_wrap">
							 	<div class="clearfix">
							 		 <a href='' data-title='<?php _e('Add Image','leap') ?>' data-label='<?php _e('Add Image','leap') ?>' data-multi='false' class='image_upload button-default'><?php _e('Upload','leap') ?></a>
									 <input type="text" name="custom_profile_image" id="custom_profile_image" value="<?php echo esc_attr( get_the_author_meta( 'custom_profile_image', $user->ID ) ); ?>" class="regular-text" />
							 	</div>
						<p class="description"><?php _e('You can add your own profile image from here.','leap') ?></p>
					</td>
				</tr>
				<tr>
					<th><label for="leap_designation"><?php _e('Set Designation','leap') ?></label></th>

					<td class="image_upload_wrap">
							 	<div class="clearfix">
									 <input type="text" name="leap_designation" id="leap_designation" value="<?php echo $desig; ?>" class="regular-text" />
							 	</div>
						<p class="description"><?php _e('You can add your own profile image from here, if nothing is added your gravatar will show','leap') ?></p>
					</td>
				</tr>
			</table>
		<?php }

		add_action( 'personal_options_update', 'LEAP_save_profile_fields' );
		add_action( 'edit_user_profile_update', 'LEAP_save_profile_fields' );

		function LEAP_save_profile_fields( $user_id ) {

			
			if ( !current_user_can( 'edit_user', $user_id ) )
				return false;
		 
		 	update_usermeta( $user_id, 'custom_profile_image', $_POST['custom_profile_image'] );
		 	update_usermeta( $user_id, 'leap_designation', $_POST['leap_designation'] );
		}

	}

	/**
	 * Register all of the hooks related to the public-facing functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_public_hooks() {

		function addChatModel()
		{

			$style = get_option('LEAP_compact');
			if(!$style)
				$style = 'default';

            $offline = false;

            $access_users = get_option('LEAP_chat_users');

           
			
          $logged_in_users = get_transient('leap_online_status');
          
          if($access_users &&  $access_users!='' ){
                $access_users = explode(',',$access_users);


            } else
            $access_users = array();

          $lu_flag = false;  


          if($logged_in_users && is_array($logged_in_users) ) {

           

               foreach ($access_users as $key => $user) {
                         
                     if(isset($logged_in_users[$user]))   
                        $lu_flag = true;
                } 
          }

          if(!$lu_flag)
            $offline = true;


           if( get_option('LEAP_offline') && get_option('LEAP_offline') == 'true' )
                     $offline = true;


			$icon_image = '';
		
			 if($style=='default')  :

			$icon_image =  LEAP_getImage(get_option('LEAP_compact_icon'));
			$icon_image = $icon_image['src'];

			if($icon_image  == '') :
				$icon_image = leap_chat_URL.'/sprites/i/arrow-up.png';
			endif;

			else : 
			$icon_image =  LEAP_getImage(get_option('LEAP_expand_icon'));
			$icon_image = $icon_image['src'];
			endif;

			$offline_title = get_option('LEAP_chat_offline_box_title');

			if(get_option('LEAP_compact_title')) 
				$compact_title = get_option('LEAP_compact_title'); 
			else 
				$compact_title = __('Chat With Us','leap'); 

			$chat_box_classes = '';

			//leap-hide-chat
			if( $offline ) {

				$chat_box_classes = ' leap-is-offline ';
				$compact_title =  $offline_title;
			}
			
			$leap_attr = array();
			
			if( get_option('LEAP_message_effect') )
			{
				switch(get_option('LEAP_message_effect')) {
					case 'bounce' :  $leap_attr[] =  'data-usereffect="bounceInRight"'; $leap_attr[] =  'data-operatoreffect="bounceInLeft"'; break;
					case  'fade':  $leap_attr[] =  'data-usereffect="fadeIn"'; $leap_attr[] =  'data-operatoreffect="fadeIn"'; break;
					default :  $leap_attr[] =  'data-usereffect=""'; $leap_attr[] =  'data-operatoreffect=""'; break;
				}
			}

			?>

            <div class='leap-chat-box-mobile-bubble'>
            <svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" version="1.0" x="0px" y="0px" viewBox="0 0 24 24" class="icon icons8-Speech-Bubble" >    <path d="M23,10c0,8.639-11,14-11,14v-4C5.925,20,1,15.523,1,10S5.925,0,12,0S23,4.477,23,10z"></path></svg>
             </div> 

			<div class="leap-chat-box leap-hide-chat <?php echo $chat_box_classes ?> <?php if($style=='default') echo 'leap-chat-style-compact'; else echo 'leap-chat-style-expand'?> " <?php echo join($leap_attr, ' ') ?>   id="leap-chat">
				
				<?php if($style=='default') : ?>	
				<div class="leap-chat-box-compact-bar">
					<?php if($icon_image!='') : ?><span class="leap-chat-box-compact-bar--icon"><img src="<?php echo $icon_image ?>" alt=""></span><?php endif; ?>
					<span class="leap-chat-box-compact-bar--title"><?php echo stripslashes($compact_title); ?></span>
				</div>
				<?php else : ?>
				<div class="leap-chat-box-expand-bar">
					<?php if($icon_image!='') : ?><span class="leap-chat-box-expand-bar--icon"><img src="<?php echo $icon_image ?>" alt=""></span><?php endif; ?>
					<span class="leap-chat-box-expand-bar--title"><?php echo stripslashes($compact_title); ?></span>
				</div>
				<?php endif; ?>

				<div class="leap-chat-box-header">
					<?php if( $offline ) : ?>
						<?php if(get_option('LEAP_chat_offline_box_title')) echo stripslashes(get_option('LEAP_chat_offline_box_title') ); else _e('We are Offline','leap') ?>
					<?php else : ?>
						<?php if(get_option('LEAP_chat_box_title')) echo stripslashes(get_option('LEAP_chat_box_title') ); else _e('Live 24x7','leap') ?>
					<?php endif; ?>	
					

					<a href="" class="leap-chat-box-close">&#215;</a>
				</div>
				<div class="leap-chat-box-chat-wrap">
					<div class="leap-chat-box-close-modal">
						<p><?php _e('Are you sure you want to quit ?','leap') ?></p>
						<p class="clearfix">
							<a href="" class='leap-kill-session'><?php _e('Yes','leap') ?></a>
							<a href="" class='leap-modal-close'><?php _e('No','leap') ?></a>
						</p>
					</div>	
					<div class="leap-chat-box-intro">
					<div class="leap-start-overlay"> <span   class='start-leap-chap'><?php _e('Please wait.. ','leap') ?></span></div> 
					<div class="leap-chat-box-intro-inner-wrap">	
						
						<div class="leap-chat-box-intro--form">

							<?php if( $offline ) : ?>
								
								<div class="leap-offline-success-message">
									<?php echo stripslashes(get_option('LEAP_offline_s_msg')); ?>
								</div>
								<div class="leap-offline-form">
									<div class="leap-chat-box-intro--message">
										<?php if(get_option('LEAP_offline_msg')) echo stripslashes(get_option('LEAP_offline_msg')); ?>
									</div>

									<?php 
										$inputs = array();

										if(get_option('rad_offline_tab') && get_option('rad_offline_tab')!='' )
											$inputs =  LEAP_getModuleData(get_option('rad_offline_tab'));

										foreach ($inputs as $key => $input) {
											
											?>
											<div class="leap-chat--input">
												<label for="#leap-chat-<?php echo str_replace(' ','_',trim($input['in_name'])) ?>"><?php echo stripslashes($input['in_name']) ?></label>
												<?php 
												switch($input['in_type'])
												{
													case 'textarea' :?>
													<textarea  name="leap-chat-<?php echo str_replace(' ','_',trim($input['in_name'])) ?>" id="leap-chat-<?php echo str_replace(' ','_',trim($input['in_name'])) ?>" value=""></textarea><?php break;
													case 'select' :?>
													 	<select  name="leap-chat-<?php echo str_replace(' ','_',trim($input['in_name'])) ?>" id="leap-chat-<?php echo str_replace(' ','_',trim($input['in_name'])) ?>" value="">
													 		<?php 
													 		 	$opts = explode(';',$input['in_d_opts']);
													 		 	foreach ($opts as $o) {
													 		 		echo "<option value='{$o}'>{$o}</option>";
													 		 		}	
													 		 ?>
													 	</select>
													 	<?php break;
													default : 
													 	?>
													 	<input type="text" name="leap-chat-<?php echo str_replace(' ','_',trim($input['in_name'])) ?>" id="leap-chat-<?php echo str_replace(' ','_',trim($input['in_name'])) ?>" value=""><?php
												}

												 ?>
												 <span><?php _e('Field cannot be empty.','leap') ?></span>
											</div>
											<?php


										}

									 ?>
								</div>
									
							<?php else : ?>
								<div class="leap-chat-box-intro--message">
								<?php if(get_option('LEAP_start_box_msg')) echo stripslashes(get_option('LEAP_start_box_msg')); else _e('Please Fill in the details below before starting the chat.','leap') ?>
							</div>
							<div class="leap-chat--input">
								<label for="#leap-chat-name"><?php _e('Name','leap') ?></label>
								<input type="text" name="leap-chat-name" id="leap-chat-name" value="">
								<span><?php _e('Please enter a name.','leap') ?></span>
							</div>

							<?php 
								$inputs = array();

								if(get_option('rad_tab') && get_option('rad_tab')!='' )
									$inputs =  LEAP_getModuleData(get_option('rad_tab'));

								foreach ($inputs as $key => $input) {
									
									?>
									<div class="leap-chat--input">
										<label for="#leap-chat-<?php echo str_replace(' ','_',trim($input['in_name'])) ?>"><?php echo stripslashes($input['in_name']) ?></label>
										<?php 
										switch($input['in_type'])
										{
											case 'textarea' :?>
											<textarea  name="leap-chat-<?php echo str_replace(' ','_',trim($input['in_name'])) ?>" id="leap-chat-<?php echo str_replace(' ','_',trim($input['in_name'])) ?>" value=""></textarea><?php break;
											case 'select' :?>
											 	<select  name="leap-chat-<?php echo str_replace(' ','_',trim($input['in_name'])) ?>" id="leap-chat-<?php echo str_replace(' ','_',trim($input['in_name'])) ?>" value="">
											 		<?php 
											 		 	$opts = explode(';',$input['in_d_opts']);
											 		 	foreach ($opts as $o) {
											 		 		echo "<option value='{$o}'>{$o}</option>";
											 		 		}	
											 		 ?>
											 	</select>
											 	<?php break;
											default : 
											 	?>
											 	<input type="text" name="leap-chat-<?php echo str_replace(' ','_',trim($input['in_name'])) ?>" id="leap-chat-<?php echo str_replace(' ','_',trim($input['in_name'])) ?>" value=""><?php
										}

										 ?>
									</div>
									<?php


								}

							 ?>
							<?php endif; ?>
						</div>

						<?php if( $offline ) : ?>
						 <div class="leap-offline-button">
						 	<a href="" class=''><?php _e('Send','leap') ?></a>
						 </div>				
						<?php else : ?>	
						 <div class="leap-start-chat">
						 	<a href="" class=''><?php _e('Start Chat','leap') ?></a>
						 </div>
						<?php endif; ?>

						 </div> 
					</div>	
					
					<div class="leap-chat-area">
						<div class="leap-chat-box-body">
							<!-- <span class='leap-past-chat-triggers'>View Past Chats</span> -->

							<?php 
								$meta_show = get_option('LEAP_meta_op');
								if(!$meta_show)
									$meta_show = 'show';

								if($meta_show!='hide') :
							?>
							<div class="leap-chat-operator-meta">
								 <div class="leap-chat-avatar">
								 	<img src="" alt="avatar">
								 </div>
								 <div class="leap-operator-meta">
								 	<h4 id="leap-operator-name"></h4>
								 	<h6 id="leap-operator-desig"></h6>
								 </div>
							</div>
							<?php endif; ?>
							<div class="leap-chat-box-body--canvas">
								
							</div>
							<div class='leap-chat-typing-indicator'>
								  <div class=''></div>
								  <div class=''></div>
								  <div class=''></div>
							</div>
						</div>
						<div class="leap-chat-box-footer">
							<textarea class="leap-chat-box-footer--input"></textarea>
							<a href="" class='leap-chat-box-footer--send' ><?php _e('Send','leap') ?></a>
							
						</div>
					</div>	

				</div>
				
				 <div class="leap-chat-box-end"> 
				 	<p>
				 		<span   class=''><?php _e('Thank you for chatting with us !') ?> </span>
				 	</p>
				 		<a class="leap-chat-restart" href=''><?php _e('Chat Again','leap') ?></a>
				 </div>
			</div>

			<?php $sound = get_option('LEAP_sound'); if(!$sound) $sound = 'true'; ?>
			
			<?php if($sound!=='false') : 
				$sound_url =  leap_chat_URL.'/sprites/sound.mp3';

				if( get_option('LEAP_custom_sound') && trim(get_option('LEAP_custom_sound')) !='' )
					$sound_url = get_option('LEAP_custom_sound');

			?>	
			<div class="leap-audio-notification">
								<audio autobuffer id="leap-chat-audio">
									<source src="<?php echo $sound_url ?>">
								</audio>
							</div>
			<?php endif; ?>				
			<script>
				var LEAP_USER_INFO =    '<?php echo $_SERVER['REMOTE_ADDR']  ?>' ,
				 LEAP_START_MESSAGE =  '<?php  if(get_option('LEAP_start_msg')) echo get_option('LEAP_start_msg');  ?>';
			</script>
			<?php
		}

		add_action('init','initLeapChatMods');

		function initLeapChatMods() {

			$show_plugin = true;

			if( get_option('LEAP_logged_user_only') == 'yes' ) : 
				if(!  is_user_logged_in() ){
					$show_plugin = false;
				}
					
			endif;

			if( get_option('LEAP_preview') && get_option('LEAP_preview') == "true"  && ! current_user_can('manage_options') )
				$show_plugin = false;

				
			if($show_plugin) {
			
				add_action('wp_footer','addChatModel');
			
			}
			
		}
		
		add_action( 'wp_enqueue_scripts', array( $this, 'registerChatScripts' )  );

		function leap_add_Variables()
		{
			
			$font = get_option('LEAP_google_font');
			if( ! $font )
				$font = 'Open Sans';


			echo "
			<script>var leap_listener_url = '".admin_url( 'admin-ajax.php' )."';</script>
			";

			if(!is_admin()) :
				$bg = $pos = '';
				$cbg = '';
				if(get_option('LEAP_compact_bgimage')) {
					$bg = LEAP_getImage(get_option('LEAP_compact_bgimage'));
					$bg = $bg['src'];
					$cbg .=  "background-image:url(".$bg.");";
				}

				if(get_option('LEAP_compact_posimage'))
				{
					$pos = get_option('LEAP_compact_posimage');
					if($pos!='')
						$cbg .=  "background-position:".$pos.";";
				}	
				
				$fz = '';
				if(get_option('LEAP_title_fz'))
					$fz = get_option('LEAP_title_fz');

				if(get_option('LEAP_compactbar_bg'))
				{
					$cbg .=  "background-color:".get_option('LEAP_compactbar_bg').";";
				}
			?>
			<style type="text/css" media="screen">
                
                <?php if(get_option('LEAP_mobile_hide') && get_option('LEAP_mobile_hide')=='true') : ?>
                        @media only screen and (max-width:767px) { div.leap-chat-box { display: none;  } }
                <?php endif; ?>

				div.leap-chat-box {  font-family:"<?php echo $font ?>",Arial; }
				div.leap-chat-box-compact-bar , div.leap-chat-box-expand-bar { <?php echo $cbg ?>  color:<?php echo get_option('LEAP_compactbar_title') ?>; }
				
				div.leap-chat-box-header { background: <?php echo get_option('LEAP_chatbar_bg'); ?>; color:<?php echo get_option('LEAP_chatbar_title') ?>; }
				div.leap-chat-box , .leap-chat-box-end{ background: <?php echo get_option('LEAP_chatbox'); ?>; }
				div.leap-chat-box-intro--message,div.leap-chat-box-intro--form label ,  div.leap-chat-box div.leap-chat-box-close-modal  p {  color:<?php echo get_option('LEAP_chatbox_text') ?>; }
				div.leap-chat-box-intro--form input[type=text], div.leap-chat-box-intro--form textarea, div.leap-chat-box-intro--form select,  textarea.leap-chat-box-footer--input  {
							background:<?php echo get_option('LEAP_chatbox_input_bg') ?>;
							border-color:<?php echo get_option('LEAP_chatbox_input_br') ?>;
							color:<?php echo get_option('LEAP_chatbox_input_cr') ?>;

				}
				
				.leap-chat-box-expand-bar--title  { top:<?php echo get_option('LEAP_title_pos_top') ?>; left:<?php echo get_option('LEAP_title_pos_left') ?>;  width:<?php echo get_option('LEAP_title_pos_width') ?>;  color:<?php echo get_option('LEAP_compactbar_title') ?>; font-size:<?php echo $fz ?>; }
				.leap-chat-box-expand-bar--icon  { top:<?php echo get_option('LEAP_image_pos_top') ?>; left:<?php echo get_option('LEAP_image_pos_left') ?>; }

				a.leap-chat-box-footer--send ,div.leap-start-chat a,div.leap-offline-button  a ,a.start-leap-chap,  div.leap-chat-box div.leap-chat-box-close-modal a  , a.leap-chat-restart{ background:<?php echo get_option('LEAP_chatbox_button_bg') ?>; color:<?php echo get_option('LEAP_chatbox_button_cr') ?>; }

                a.leap-chat-box-footer--send:hover ,div.leap-start-chat a:hover,div.leap-offline-button  a:hover ,a.start-leap-chap:hover,  div.leap-chat-box div.leap-chat-box-close-modal a:hover  , a.leap-chat-restart:hover{ background:<?php echo get_option('LEAP_chatbox_button_bg_hover') ?>; color:<?php echo get_option('LEAP_chatbox_button_cr_hover') ?>; }
				div.leap-chat-box-user-msg , div.leap-chat-box-operator-msg { color:<?php echo get_option('LEAP_chatbox_msg'); ?>; }

				div.leap-chat-box-operator-wrap span, div.leap-chat-box-user-wrap span { color:<?php echo get_option('LEAP_chatbox_label'); ?>; }
				div.leap-chat-box-operator-wrap small, div.leap-chat-box-user-wrap small { color:<?php echo get_option('LEAP_chatbox_time'); ?>; }
				div.leap-chat-operator-meta{ background:<?php echo get_option('LEAP_chatbox_op_bg'); ?>; border-color:<?php echo get_option('LEAP_chatbox_op_br'); ?>;   }
				div.leap-operator-meta h4 { color:<?php echo get_option('LEAP_chatbox_op_title'); ?>;  }
				div.leap-operator-meta h6 { color:<?php echo get_option('LEAP_chatbox_op_subtitle'); ?>;  }
				
				<?php if(get_option('LEAP_chat_offline_height') && get_option('LEAP_chat_offline_height')!='') : ?>	
				div.leap-chat-box.leap-is-offline { height:<?php echo get_option('LEAP_chat_offline_height') ?>px; }
				div.leap-chat-box.leap-is-offline div.leap-chat-box-chat-wrap { height:<?php echo intval(get_option('LEAP_chat_offline_height')) - 40; ?>px; }
				<?php endif; ?>	

			</style>

			<?php
			endif;

		}

		add_action('wp_head','leap_add_Variables');
		add_action('admin_head','leap_add_Variables');

	}

	

	/**
	 * Run the loader to execute all of the hooks with WordPress.
	 *
	 * @since    1.0.0
	 */
	public function run() {
		$this->loader->run();
	}

	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 *
	 * @since     1.0.0
	 * @return    string    The name of the plugin.
	 */
	public function get_plugin_name() {
		return $this->plugin_name;
	}

	/**
	 * The reference to the class that orchestrates the hooks with the plugin.
	 *
	 * @since     1.0.0
	 * @return    leap_chat_Loader    Orchestrates the hooks of the plugin.
	 */
	public function get_loader() {
		return $this->loader;
	}

	/**
	 * Retrieve the version number of the plugin.
	 *
	 * @since     1.0.0
	 * @return    string    The version number of the plugin.
	 */
	public function get_version() {
		return $this->version;
	}

}
